import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as AuditLogsAPI from 'cloudflare/resources/user/audit-logs';
import * as InvitesAPI from 'cloudflare/resources/user/invites';
import * as OrganizationsAPI from 'cloudflare/resources/user/organizations';
import * as SubscriptionsAPI from 'cloudflare/resources/user/subscriptions';
import * as BillingAPI from 'cloudflare/resources/user/billing/billing';
import * as TokensAPI from 'cloudflare/resources/user/tokens/tokens';
export declare class User extends APIResource {
    auditLogs: AuditLogsAPI.AuditLogs;
    billing: BillingAPI.Billing;
    invites: InvitesAPI.Invites;
    organizations: OrganizationsAPI.Organizations;
    subscriptions: SubscriptionsAPI.Subscriptions;
    tokens: TokensAPI.Tokens;
    /**
     * Edit part of your user details.
     */
    edit(body: UserEditParams, options?: Core.RequestOptions): Core.APIPromise<UserEditResponse>;
    /**
     * User Details
     */
    get(options?: Core.RequestOptions): Core.APIPromise<UserGetResponse>;
}
export type UserEditResponse = unknown | string | null;
export type UserGetResponse = unknown | string | null;
export interface UserEditParams {
    /**
     * The country in which the user lives.
     */
    country?: string | null;
    /**
     * User's first name
     */
    first_name?: string | null;
    /**
     * User's last name
     */
    last_name?: string | null;
    /**
     * User's telephone number
     */
    telephone?: string | null;
    /**
     * The zipcode or postal code where the user lives.
     */
    zipcode?: string | null;
}
export declare namespace User {
    export import AuditLogs = AuditLogsAPI.AuditLogs;
    export import AuditLogListParams = AuditLogsAPI.AuditLogListParams;
    export import Billing = BillingAPI.Billing;
    export import Invites = InvitesAPI.Invites;
    export import Invite = InvitesAPI.Invite;
    export import InviteEditResponse = InvitesAPI.InviteEditResponse;
    export import InviteGetResponse = InvitesAPI.InviteGetResponse;
    export import InvitesSinglePage = InvitesAPI.InvitesSinglePage;
    export import InviteEditParams = InvitesAPI.InviteEditParams;
    export import Organizations = OrganizationsAPI.Organizations;
    export import Organization = OrganizationsAPI.Organization;
    export import OrganizationDeleteResponse = OrganizationsAPI.OrganizationDeleteResponse;
    export import OrganizationGetResponse = OrganizationsAPI.OrganizationGetResponse;
    export import OrganizationsV4PagePaginationArray = OrganizationsAPI.OrganizationsV4PagePaginationArray;
    export import OrganizationListParams = OrganizationsAPI.OrganizationListParams;
    export import OrganizationDeleteParams = OrganizationsAPI.OrganizationDeleteParams;
    export import Subscriptions = SubscriptionsAPI.Subscriptions;
    export import RatePlan = SubscriptionsAPI.RatePlan;
    export import Subscription = SubscriptionsAPI.Subscription;
    export import SubscriptionComponent = SubscriptionsAPI.SubscriptionComponent;
    export import SubscriptionZone = SubscriptionsAPI.SubscriptionZone;
    export import SubscriptionUpdateResponse = SubscriptionsAPI.SubscriptionUpdateResponse;
    export import SubscriptionDeleteResponse = SubscriptionsAPI.SubscriptionDeleteResponse;
    export import SubscriptionEditResponse = SubscriptionsAPI.SubscriptionEditResponse;
    export import SubscriptionGetResponse = SubscriptionsAPI.SubscriptionGetResponse;
    export import SubscriptionUpdateParams = SubscriptionsAPI.SubscriptionUpdateParams;
    export import SubscriptionDeleteParams = SubscriptionsAPI.SubscriptionDeleteParams;
    export import SubscriptionEditParams = SubscriptionsAPI.SubscriptionEditParams;
    export import Tokens = TokensAPI.Tokens;
    export import CIDRList = TokensAPI.CIDRList;
    export import Policy = TokensAPI.Policy;
    export import Token = TokensAPI.Token;
    export import TokenCreateResponse = TokensAPI.TokenCreateResponse;
    export import TokenUpdateResponse = TokensAPI.TokenUpdateResponse;
    export import TokenListResponse = TokensAPI.TokenListResponse;
    export import TokenDeleteResponse = TokensAPI.TokenDeleteResponse;
    export import TokenGetResponse = TokensAPI.TokenGetResponse;
    export import TokenVerifyResponse = TokensAPI.TokenVerifyResponse;
    export import TokenListResponsesV4PagePaginationArray = TokensAPI.TokenListResponsesV4PagePaginationArray;
    export import TokenCreateParams = TokensAPI.TokenCreateParams;
    export import TokenUpdateParams = TokensAPI.TokenUpdateParams;
    export import TokenListParams = TokensAPI.TokenListParams;
    export import TokenDeleteParams = TokensAPI.TokenDeleteParams;
}
//# sourceMappingURL=user.d.ts.map