import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as TagsAPI from 'cloudflare/resources/workers-for-platforms/dispatch/namespaces/scripts/tags';
import { SinglePage } from 'cloudflare/pagination';
export declare class Tags extends APIResource {
    /**
     * Put script tags for a script uploaded to a Workers for Platforms namespace.
     */
    update(dispatchNamespace: string, scriptName: string, params: TagUpdateParams, options?: Core.RequestOptions): Core.APIPromise<TagUpdateResponse>;
    /**
     * Fetch tags from a script uploaded to a Workers for Platforms namespace.
     */
    list(dispatchNamespace: string, scriptName: string, params: TagListParams, options?: Core.RequestOptions): Core.PagePromise<TagListResponsesSinglePage, TagListResponse>;
    /**
     * Delete script tag for a script uploaded to a Workers for Platforms namespace.
     */
    delete(dispatchNamespace: string, scriptName: string, tag: string, params: TagDeleteParams, options?: Core.RequestOptions): Core.APIPromise<TagDeleteResponse | null>;
}
export declare class TagListResponsesSinglePage extends SinglePage<TagListResponse> {
}
export type TagUpdateResponse = Array<string>;
/**
 * Tag to help you manage your Worker
 */
export type TagListResponse = string;
export type TagDeleteResponse = unknown;
export interface TagUpdateParams {
    /**
     * Path param: Identifier
     */
    account_id: string;
    /**
     * Body param: Tags to help you manage your Workers
     */
    body: Array<string>;
}
export interface TagListParams {
    /**
     * Identifier
     */
    account_id: string;
}
export interface TagDeleteParams {
    /**
     * Identifier
     */
    account_id: string;
}
export declare namespace Tags {
    export import TagUpdateResponse = TagsAPI.TagUpdateResponse;
    export import TagListResponse = TagsAPI.TagListResponse;
    export import TagDeleteResponse = TagsAPI.TagDeleteResponse;
    export import TagListResponsesSinglePage = TagsAPI.TagListResponsesSinglePage;
    export import TagUpdateParams = TagsAPI.TagUpdateParams;
    export import TagListParams = TagsAPI.TagListParams;
    export import TagDeleteParams = TagsAPI.TagDeleteParams;
}
//# sourceMappingURL=tags.d.ts.map