import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as CAsAPI from 'cloudflare/resources/zero-trust/access/applications/cas';
import { SinglePage } from 'cloudflare/pagination';
export declare class CAs extends APIResource {
    /**
     * Generates a new short-lived certificate CA and public key.
     */
    create(uuid: string, params?: CACreateParams, options?: Core.RequestOptions): Core.APIPromise<CACreateResponse>;
    create(uuid: string, options?: Core.RequestOptions): Core.APIPromise<CACreateResponse>;
    /**
     * Lists short-lived certificate CAs and their public keys.
     */
    list(params?: CAListParams, options?: Core.RequestOptions): Core.PagePromise<CAsSinglePage, CA>;
    list(options?: Core.RequestOptions): Core.PagePromise<CAsSinglePage, CA>;
    /**
     * Deletes a short-lived certificate CA.
     */
    delete(uuid: string, params?: CADeleteParams, options?: Core.RequestOptions): Core.APIPromise<CADeleteResponse>;
    delete(uuid: string, options?: Core.RequestOptions): Core.APIPromise<CADeleteResponse>;
    /**
     * Fetches a short-lived certificate CA and its public key.
     */
    get(uuid: string, params?: CAGetParams, options?: Core.RequestOptions): Core.APIPromise<CAGetResponse>;
    get(uuid: string, options?: Core.RequestOptions): Core.APIPromise<CAGetResponse>;
}
export declare class CAsSinglePage extends SinglePage<CA> {
}
export interface CA {
    /**
     * The ID of the CA.
     */
    id?: string;
    /**
     * The Application Audience (AUD) tag. Identifies the application associated with
     * the CA.
     */
    aud?: string;
    /**
     * The public key to add to your SSH server configuration.
     */
    public_key?: string;
}
export type CACreateResponse = unknown | string | null;
export interface CADeleteResponse {
    /**
     * The ID of the CA.
     */
    id?: string;
}
export type CAGetResponse = unknown | string | null;
export interface CACreateParams {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    account_id?: string;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    zone_id?: string;
}
export interface CAListParams {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    account_id?: string;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    zone_id?: string;
}
export interface CADeleteParams {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    account_id?: string;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    zone_id?: string;
}
export interface CAGetParams {
    /**
     * The Account ID to use for this endpoint. Mutually exclusive with the Zone ID.
     */
    account_id?: string;
    /**
     * The Zone ID to use for this endpoint. Mutually exclusive with the Account ID.
     */
    zone_id?: string;
}
export declare namespace CAs {
    export import CA = CAsAPI.CA;
    export import CACreateResponse = CAsAPI.CACreateResponse;
    export import CADeleteResponse = CAsAPI.CADeleteResponse;
    export import CAGetResponse = CAsAPI.CAGetResponse;
    export import CAsSinglePage = CAsAPI.CAsSinglePage;
    export import CACreateParams = CAsAPI.CACreateParams;
    export import CAListParams = CAsAPI.CAListParams;
    export import CADeleteParams = CAsAPI.CADeleteParams;
    export import CAGetParams = CAsAPI.CAGetParams;
}
//# sourceMappingURL=cas.d.ts.map