import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as BookmarksAPI from 'cloudflare/resources/zero-trust/access/bookmarks';
import { SinglePage } from 'cloudflare/pagination';
export declare class Bookmarks extends APIResource {
    /**
     * Create a new Bookmark application.
     */
    create(identifier: string, uuid: string, body: BookmarkCreateParams, options?: Core.RequestOptions): Core.APIPromise<Bookmark>;
    /**
     * Updates a configured Bookmark application.
     */
    update(identifier: string, uuid: string, body: BookmarkUpdateParams, options?: Core.RequestOptions): Core.APIPromise<Bookmark>;
    /**
     * Lists Bookmark applications.
     */
    list(identifier: string, options?: Core.RequestOptions): Core.PagePromise<BookmarksSinglePage, Bookmark>;
    /**
     * Deletes a Bookmark application.
     */
    delete(identifier: string, uuid: string, body: BookmarkDeleteParams, options?: Core.RequestOptions): Core.APIPromise<BookmarkDeleteResponse>;
    /**
     * Fetches a single Bookmark application.
     */
    get(identifier: string, uuid: string, options?: Core.RequestOptions): Core.APIPromise<Bookmark>;
}
export declare class BookmarksSinglePage extends SinglePage<Bookmark> {
}
export interface Bookmark {
    /**
     * The unique identifier for the Bookmark application.
     */
    id?: string;
    /**
     * Displays the application in the App Launcher.
     */
    app_launcher_visible?: boolean;
    created_at?: string;
    /**
     * The domain of the Bookmark application.
     */
    domain?: string;
    /**
     * The image URL for the logo shown in the App Launcher dashboard.
     */
    logo_url?: string;
    /**
     * The name of the Bookmark application.
     */
    name?: string;
    updated_at?: string;
}
export interface BookmarkDeleteResponse {
    /**
     * UUID
     */
    id?: string;
}
export type BookmarkCreateParams = unknown;
export type BookmarkUpdateParams = unknown;
export type BookmarkDeleteParams = unknown;
export declare namespace Bookmarks {
    export import Bookmark = BookmarksAPI.Bookmark;
    export import BookmarkDeleteResponse = BookmarksAPI.BookmarkDeleteResponse;
    export import BookmarksSinglePage = BookmarksAPI.BookmarksSinglePage;
    export import BookmarkCreateParams = BookmarksAPI.BookmarkCreateParams;
    export import BookmarkUpdateParams = BookmarksAPI.BookmarkUpdateParams;
    export import BookmarkDeleteParams = BookmarksAPI.BookmarkDeleteParams;
}
//# sourceMappingURL=bookmarks.d.ts.map