import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as AccessRequestsAPI from 'cloudflare/resources/zero-trust/access/logs/access-requests';
export declare class AccessRequests extends APIResource {
    /**
     * Gets a list of Access authentication audit logs for an account.
     */
    list(identifier: string, options?: Core.RequestOptions): Core.APIPromise<AccessRequestListResponse | null>;
}
export interface AccessRequests {
    /**
     * The event that occurred, such as a login attempt.
     */
    action?: string;
    /**
     * The result of the authentication event.
     */
    allowed?: boolean;
    /**
     * The URL of the Access application.
     */
    app_domain?: string;
    /**
     * The unique identifier for the Access application.
     */
    app_uid?: string;
    /**
     * The IdP used to authenticate.
     */
    connection?: string;
    created_at?: string;
    /**
     * The IP address of the authenticating user.
     */
    ip_address?: string;
    /**
     * The unique identifier for the request to Cloudflare.
     */
    ray_id?: string;
    /**
     * The email address of the authenticating user.
     */
    user_email?: string;
}
export type AccessRequestListResponse = Array<AccessRequests>;
export declare namespace AccessRequests {
    export import AccessRequests = AccessRequestsAPI.AccessRequests;
    export import AccessRequestListResponse = AccessRequestsAPI.AccessRequestListResponse;
}
//# sourceMappingURL=access-requests.d.ts.map