import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as RiskScoringAPI from 'cloudflare/resources/zero-trust/risk-scoring/risk-scoring';
import * as BehavioursAPI from 'cloudflare/resources/zero-trust/risk-scoring/behaviours';
import * as SummaryAPI from 'cloudflare/resources/zero-trust/risk-scoring/summary';
export declare class RiskScoring extends APIResource {
    behaviours: BehavioursAPI.Behaviours;
    summary: SummaryAPI.Summary;
    /**
     * Get risk event/score information for a specific user
     */
    get(accountIdentifier: string, userId: string, query?: RiskScoringGetParams, options?: Core.RequestOptions): Core.APIPromise<RiskScoringGetResponse>;
    get(accountIdentifier: string, userId: string, options?: Core.RequestOptions): Core.APIPromise<RiskScoringGetResponse>;
    /**
     * Clear the risk score for a particular user
     */
    reset(accountIdentifier: string, userId: string, options?: Core.RequestOptions): Core.APIPromise<RiskScoringResetResponse>;
}
export interface RiskScoringGetResponse {
    email?: string;
    events?: Array<RiskScoringGetResponse.Event>;
    last_reset_time?: string | null;
    name?: string;
    risk_level?: 'low' | 'medium' | 'high' | null;
}
export declare namespace RiskScoringGetResponse {
    interface Event {
        id: string;
        name: string;
        risk_level: 'low' | 'medium' | 'high' | null;
        timestamp: string;
        event_details?: unknown;
    }
}
export type RiskScoringResetResponse = unknown | string | null;
export interface RiskScoringGetParams {
    direction?: 'desc' | 'asc';
    order_by?: 'timestamp' | 'risk_level';
    page?: number;
    per_page?: number;
}
export declare namespace RiskScoring {
    export import RiskScoringGetResponse = RiskScoringAPI.RiskScoringGetResponse;
    export import RiskScoringResetResponse = RiskScoringAPI.RiskScoringResetResponse;
    export import RiskScoringGetParams = RiskScoringAPI.RiskScoringGetParams;
    export import Behaviours = BehavioursAPI.Behaviours;
    export import BehaviourUpdateResponse = BehavioursAPI.BehaviourUpdateResponse;
    export import BehaviourGetResponse = BehavioursAPI.BehaviourGetResponse;
    export import BehaviourUpdateParams = BehavioursAPI.BehaviourUpdateParams;
    export import Summary = SummaryAPI.Summary;
    export import SummaryGetResponse = SummaryAPI.SummaryGetResponse;
    export import SummaryGetParams = SummaryAPI.SummaryGetParams;
}
//# sourceMappingURL=risk-scoring.d.ts.map