import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as SSLRecommenderAPI from 'cloudflare/resources/zones/settings/ssl-recommender';
export declare class SSLRecommenderResource extends APIResource {
    /**
     * Enrollment in the SSL/TLS Recommender service which tries to detect and
     * recommend (by sending periodic emails) the most secure SSL/TLS setting your
     * origin servers support.
     */
    edit(params: SSLRecommenderEditParams, options?: Core.RequestOptions): Core.APIPromise<SSLRecommender>;
    /**
     * Enrollment in the SSL/TLS Recommender service which tries to detect and
     * recommend (by sending periodic emails) the most secure SSL/TLS setting your
     * origin servers support.
     */
    get(params: SSLRecommenderGetParams, options?: Core.RequestOptions): Core.APIPromise<SSLRecommender>;
}
/**
 * Enrollment in the SSL/TLS Recommender service which tries to detect and
 * recommend (by sending periodic emails) the most secure SSL/TLS setting your
 * origin servers support.
 */
export interface SSLRecommender {
    /**
     * Enrollment value for SSL/TLS Recommender.
     */
    id?: 'ssl_recommender';
    /**
     * ssl-recommender enrollment setting.
     */
    enabled?: boolean;
}
export interface SSLRecommenderEditParams {
    /**
     * Path param: Identifier
     */
    zone_id: string;
    /**
     * Body param: Enrollment in the SSL/TLS Recommender service which tries to detect
     * and recommend (by sending periodic emails) the most secure SSL/TLS setting your
     * origin servers support.
     */
    value: SSLRecommender;
}
export interface SSLRecommenderGetParams {
    /**
     * Identifier
     */
    zone_id: string;
}
export declare namespace SSLRecommenderResource {
    export import SSLRecommender = SSLRecommenderAPI.SSLRecommender;
    export import SSLRecommenderEditParams = SSLRecommenderAPI.SSLRecommenderEditParams;
    export import SSLRecommenderGetParams = SSLRecommenderAPI.SSLRecommenderGetParams;
}
//# sourceMappingURL=ssl-recommender.d.ts.map